@@ -7,10 +7,9 @@ from typing import Dict, List, Tuple, Union
 import inject
 
 from ahbicht.content_evaluation.evaluationdatatypes import EvaluatableData, EvaluatableDataProvider
-from ahbicht.content_evaluation.rc_evaluators import RcEvaluator
+from ahbicht.content_evaluation.token_logic_provider import TokenLogicProvider
 from ahbicht.expressions.condition_expression_parser import extract_categorized_keys_from_tree
 from ahbicht.expressions.condition_nodes import Hint, RequirementConstraint, UnevaluatedFormatConstraint
-from ahbicht.expressions.hints_provider import HintsProvider
 
 # TRCTransformerArgument is a union of nodes that are already evaluated from a Requirement Constraint (RC) perspective.
 # The Format Constraints (FC) might still be unevaluated. That's why the return type used in the
@@ -29,8 +28,7 @@ class ConditionNodeBuilder:
     """
 
     def __init__(self, condition_keys: List[str]):
-        self.hints_provider: HintsProvider = inject.instance(HintsProvider)  # type:ignore[assignment]
-        self.rc_evaluator: RcEvaluator = inject.instance(RcEvaluator)  # type:ignore[assignment]
+        self.token_logic_provider: TokenLogicProvider = inject.instance(TokenLogicProvider)  # type:ignore[assignment]
         self.condition_keys = condition_keys
         (
             self.requirement_constraints_condition_keys,
@@ -50,9 +48,14 @@ class ConditionNodeBuilder:
             categorized_keys.format_constraint_keys,
         )
 
-    async def _build_hint_nodes(self) -> Dict[str, Hint]:
+    @inject.params(evaluatable_data=EvaluatableDataProvider)  # injects what has been bound to the EvaluatableData type
+    # search for binder.bind_to_provider(EvaluatableDataProvider, your_function_that_returns_evaluatable_data_goes_here)
+    async def _build_hint_nodes(self, evaluatable_data: EvaluatableData) -> Dict[str, Hint]:
         """Builds Hint nodes from their condition keys by getting all hint texts from the HintsProvider."""
-        return await self.hints_provider.get_hints(self.hints_condition_keys)
+        hints_provider = self.token_logic_provider.get_hints_provider(
+            evaluatable_data.edifact_format, evaluatable_data.edifact_format_version
+        )
+        return await hints_provider.get_hints(self.hints_condition_keys)
 
     def _build_unevaluated_format_constraint_nodes(self) -> Dict[str, UnevaluatedFormatConstraint]:
         """Build unevaluated format constraint nodes."""
@@ -70,7 +73,10 @@ class ConditionNodeBuilder:
         Build requirement constraint nodes by evaluating the constraints
         with the help of the respective Evaluator.
         """
-        evaluated_conditions_fulfilled_attribute = await self.rc_evaluator.evaluate_conditions(
+        rc_evaluator = self.token_logic_provider.get_rc_evaluator(
+            evaluatable_data.edifact_format, evaluatable_data.edifact_format_version
+        )
+        evaluated_conditions_fulfilled_attribute = await rc_evaluator.evaluate_conditions(
             condition_keys=self.requirement_constraints_condition_keys, evaluatable_data=evaluatable_data
         )
         evaluated_requirement_constraints: Dict[str, RequirementConstraint] = {}
@@ -86,7 +92,8 @@ class ConditionNodeBuilder:
         requirement_constraint_nodes = (
             await self._build_requirement_constraint_nodes()  # pylint:disable=no-value-for-parameter
         )
-        hint_nodes = await self._build_hint_nodes()
+        # the missing value is injected automatically
+        hint_nodes = await self._build_hint_nodes()  # pylint:disable=no-value-for-parameter
         unevaluated_format_constraint_nodes = self._build_unevaluated_format_constraint_nodes()
         input_nodes: Dict[str, TRCTransformerArgument] = {
             **requirement_constraint_nodes,
