@@ -7,16 +7,22 @@ import pytest  # type:ignore[import]
 import pytest_asyncio  # type:ignore[import]
 
 from ahbicht.content_evaluation.content_evaluation_result import ContentEvaluationResult
-from ahbicht.content_evaluation.evaluationdatatypes import EvaluatableData
+from ahbicht.content_evaluation.evaluationdatatypes import EvaluatableDataProvider
 from ahbicht.content_evaluation.evaluator_factory import create_and_inject_hardcoded_evaluators
-from ahbicht.content_evaluation.rc_evaluators import RcEvaluator
+from ahbicht.content_evaluation.token_logic_provider import SingletonTokenLogicProvider, TokenLogicProvider
 from ahbicht.evaluation_results import FormatConstraintEvaluationResult, RequirementConstraintEvaluationResult
 from ahbicht.expressions.ahb_expression_evaluation import evaluate_ahb_expression_tree
 from ahbicht.expressions.ahb_expression_parser import parse_ahb_expression_to_single_requirement_indicator_expressions
 from ahbicht.expressions.condition_nodes import ConditionFulfilledValue, EvaluatedFormatConstraint
 from ahbicht.expressions.enums import ModalMark, PrefixOperator, RequirementIndicator
 from ahbicht.expressions.expression_resolver import parse_expression_including_unresolved_subexpressions
-from ahbicht.expressions.hints_provider import HintsProvider
+from unittests.defaults import (
+    default_test_format,
+    default_test_version,
+    empty_default_hints_provider,
+    empty_default_rc_evaluator,
+    return_empty_dummy_evaluatable_data,
+)
 
 
 class TestAHBExpressionEvaluation:
@@ -24,10 +30,12 @@ class TestAHBExpressionEvaluation:
 
     @pytest_asyncio.fixture()
     def setup_and_teardown_injector(self):
+
         inject.clear_and_configure(
-            lambda binder: binder.bind(HintsProvider, AsyncMock(wraps=HintsProvider)).bind(
-                RcEvaluator, AsyncMock(wraps=RcEvaluator)
-            )
+            lambda binder: binder.bind(
+                TokenLogicProvider,
+                SingletonTokenLogicProvider([empty_default_hints_provider, empty_default_rc_evaluator]),
+            ).bind_to_provider(EvaluatableDataProvider, return_empty_dummy_evaluatable_data)
         )
         yield
         inject.clear()
@@ -215,10 +223,12 @@ class TestAHBExpressionEvaluation:
         tree_b = await parse_expression_including_unresolved_subexpressions(ahb_expression)
         # it's OK/expected that the trees look different depending on whether sub expressions are resolved or not
         # but in any case the evaluation result should look the same
-        def get_evaluatable_data():
-            return None
-
-        create_and_inject_hardcoded_evaluators(content_evaluation_result, get_evaluatable_data)
+        create_and_inject_hardcoded_evaluators(
+            content_evaluation_result,
+            evaluatable_data_provider=return_empty_dummy_evaluatable_data,
+            edifact_format=default_test_format,
+            edifact_format_version=default_test_version,
+        )
         evaluation_input = "something has to be here but it's not important what"
         evaluation_result_a = await evaluate_ahb_expression_tree(tree_a, entered_input=evaluation_input)
         evaluation_result_b = await evaluate_ahb_expression_tree(tree_b, entered_input=evaluation_input)
